==> jira-troubleticketer-26.0.0-20200211.000934-62-sources.jar: org/opennms/netmgt/ticketer/jira/commands/ShowConfigCommand.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.ticketer.jira.commands;

import java.util.Properties;

import org.apache.karaf.shell.api.action.Action;
import org.apache.karaf.shell.api.action.Command;
import org.apache.karaf.shell.api.action.lifecycle.Service;
import org.apache.karaf.shell.console.OsgiCommandSupport;
import org.opennms.netmgt.ticketer.jira.JiraTicketerPlugin;

@Command(scope = "opennms-jira", name = "show-config", description="Shows the current configuration for the Jira Ticketer Plugin")
@org.apache.karaf.shell.commands.Command(scope = "opennms-jira", name = "show-config", description="Shows the current configuration for the Jira Ticketer Plugin")
@Service
public class ShowConfigCommand extends OsgiCommandSupport implements Action {

    @Override
    public Object execute() throws Exception {
        Properties properties = JiraTicketerPlugin.getConfig().getProperties();
        for (String eachKey : properties.stringPropertyNames()) {
            System.out.println(eachKey + " = " + properties.getProperty(eachKey));
        }
        return null;
    }

    @Override
    @Deprecated
    protected final Object doExecute() throws Exception {
        return execute();
    }

}

==> jira-troubleticketer-26.2.0-sources.jar: org/opennms/netmgt/ticketer/jira/commands/ShowConfigCommand.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.ticketer.jira.commands;

import java.util.Properties;

import org.apache.karaf.shell.api.action.Action;
import org.apache.karaf.shell.api.action.Command;
import org.apache.karaf.shell.api.action.lifecycle.Service;
import org.apache.karaf.shell.console.OsgiCommandSupport;
import org.opennms.netmgt.ticketer.jira.JiraTicketerPlugin;

@Command(scope = "opennms", name = "jira-show-config", description="Shows the current configuration for the Jira Ticketer Plugin")
@org.apache.karaf.shell.commands.Command(scope = "opennms", name = "jira-show-config", description="Shows the current configuration for the Jira Ticketer Plugin")
@Service
public class ShowConfigCommand extends OsgiCommandSupport implements Action {

    @Override
    public Object execute() throws Exception {
        Properties properties = JiraTicketerPlugin.getConfig().getProperties();
        for (String eachKey : properties.stringPropertyNames()) {
            System.out.println(eachKey + " = " + properties.getProperty(eachKey));
        }
        return null;
    }

    @Override
    @Deprecated
    protected final Object doExecute() throws Exception {
        return execute();
    }

}
